@@ -1,6 +1,8 @@
 from .gemtext import *
 import datetime
 from io import StringIO
+import iso8601
+import copy
 
 class GemMailSender:
     address = ""
@@ -19,13 +21,13 @@ class GemMail:
     def __init__(self) -> None:
         pass
 
-    def copy(self):
+    def deepcopy(self):
         result = GemMail()
-        result.Subject = self.Subject
-        result.Senders = self.Senders.copy()
-        result.Receivers = self.Receivers.copy()
-        result.Timestamps = self.Timestamps.copy()
-        result.GemText = self.GemText.copy()
+        result.Subject = copy.copy(self.Subject)
+        result.Senders = copy.deepcopy(self.Senders)
+        result.Receivers = copy.deepcopy(self.Receivers)
+        result.Timestamps = copy.deepcopy(self.Timestamps)
+        result.GemText = self.GemText.deepcopy()
         return result
     
     def containsSender(self, address):
@@ -77,7 +79,7 @@ class GemMail:
         for index, t in enumerate(self.Timestamps):
             if index > 0:
                 result.write(",")
-            result.write(t.strftime('%Y-%m-%dT%H:%M:%S.%f%z'))
+            result.write(t.strftime('%Y-%m-%dT%H:%M:%SZ'))
         result.write("\n")
 
         # Write the rest of the message body
@@ -110,7 +112,7 @@ class GemMail:
         # Timestamps
         for index, t in enumerate(self.Timestamps):
             result.write("@ ")
-            result.write(t.strftime('%Y-%m-%dT%H:%M:%S%z'))
+            result.write(t.strftime('%Y-%m-%dT%H:%M:%SZ'))
             result.write("\n")
 
         # Write the rest of the message body
@@ -151,7 +153,7 @@ def parseGemMail_B(gemmail_text = "") -> GemMail:
                 result.Receivers[part] = ()
         elif line.startswith("@"):
             line = line.removeprefix("@").strip()
-            dt = datetime.datetime.strptime(line, '%Y-%m-%dT%H:%M:%S%z')
+            dt = iso8601.parse_date(line)
             result.Timestamps.append(dt)
     result.GemText = parseGemText(gemmail_text)
     result.Subject = result.GemText.firstLevel1Heading
@@ -191,7 +193,7 @@ def parseGemMail_C(gemmail_text = ""):
                 t = t.strip()
                 if t == "":
                     continue
-                dt = datetime.datetime.strptime(line, '%Y-%m-%dT%H:%M:%S%z')
+                dt = iso8601.parse_date(line)
                 result.Timestamps.append(dt)
     result.GemText = parseGemText('\n'.join(lines[3:]))
     result.Subject = result.GemText.firstLevel1Heading
